#
# spec file for package libdv
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}

%if "%{flavor}" == "playdv"
%bcond_without playdv
%define tools_description playdv sample application
%define psuffix -playdv
%else
%bcond_with playdv
%define tools_description encodedv, dubdv and dvconnect tools
%endif
%define sname libdv

Name:           libdv%{?psuffix}
Version:        1.0.0
Release:        180.1
Summary:        The Quasar DV Codec
License:        GPL-2.0-or-later
Group:          Development/Libraries/Other
URL:            http://libdv.sourceforge.net/
Source:         http://sourceforge.net/projects/libdv/files/libdv/%{version}/%{sname}-%{version}.tar.gz
Source2:        baselibs.conf
# PATCH-FIX-UPSTREAM libdv-gtk2.patch vuntz@opensuse.org -- Patch from debian, to use GTK+ 2.x
Patch1:         libdv-gtk2.patch
Patch2:         libdv.omit-excessive-warnings.patch
Patch3:         libdv.non_x86-reorder_block.patch
Patch4:         libdv-filesizecheck.patch
Patch5:         libdv-1.0.0-textrels-selinux.patch
Patch6:         libdv-v4l-2.6.38.patch
Patch7:         libdv-fix-no-add-needed.patch
Patch8:         libdv-endian.patch
Patch9:         libdv-visibility.patch
BuildRequires:  libtool
BuildRequires:  libv4l-devel >= 0.8.4
BuildRequires:  pkg-config
BuildRequires:  popt-devel
%if %{with playdv}
BuildRequires:  gtk2-devel
BuildRequires:  libXv-devel
BuildRequires:  xorg-x11-libX11-devel
BuildRequires:  xorg-x11-libXext-devel
BuildRequires:  pkgconfig(sdl)
%endif

%description
The Quasar DV codec (libdv) is a software codec for DV video, the
encoding format used by most digital camcorders, typically those that
support the IEEE 1394 (FireWire or i.Link) interface. Libdv was
developed according to the official standards for DV video: IEC 61834
and SMPTE 314M.

This package contains the %{tools_description}.

%package -n libdv4
Summary:        The Quasar DV Codec
Group:          Development/Libraries/Other

%description -n libdv4
The Quasar DV codec (libdv) is a software codec for DV video, the
encoding format used by most digital camcorders, typically those that
support the IEEE 1394 (FireWire or i.Link) interface. Libdv was
developed according to the official standards for DV video: IEC 61834
and SMPTE 314M.

%package devel
Summary:        The Quasar DV codec
Group:          Development/Libraries/Other
Requires:       libdv4 = %{version}

%description devel
The Quasar DV codec (libdv) is a software codec for DV video, the
encoding format used by most digital camcorders, typically those that
support the IEEE 1394 (a.k.a. FireWire or i.Link) interface. Libdv was
developed according to the official standards for DV video: IEC 61834
and SMPTE 314M.

%prep
%autosetup -p1 -n %{sname}-%{version}

%build
mkdir m4
%if %{without playdv}
# Dummy macro for ignored SDL, autoreconf fails otherwise
echo "AC_DEFUN([AM_PATH_SDL], [true])" >> m4/dummy_sdl.m4
%endif

autoreconf -fiv
export CFLAGS="${RPM_OPT_FLAGS/O2/O3} -fomit-frame-pointer -fPIC -DPIC -Wno-incompatible-pointer-types"
export LDFLAGS="-pie"
%configure \
	--disable-static \
%if %{with playdv}
	--enable-sdl \
%else
	--disable-sdl \
	--disable-gtk \
%endif
        %{nil}
make %{?_smp_mflags}

%install
%if "%{flavor}" == "playdv"
%make_install -C playdv
%else
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%endif

%post -n libdv4 -p /sbin/ldconfig

%postun -n libdv4 -p /sbin/ldconfig

%files
%{_bindir}/*
%doc %{_mandir}/man1/*.1.gz

%if "%{flavor}" != "playdv"
%files -n libdv4
%{_libdir}/libdv.so.*

%files devel
%{_includedir}/libdv
%{_libdir}/libdv.so
%{_libdir}/pkgconfig/libdv.pc
%endif

%changelog
* Thu Aug  1 2024 Filip Kastl <filip.kastl@suse.com>
- Add -Wno-incompatible-pointer-types to CFLAGS to enable building
  for 32bit with GCC 14.
* Tue May 17 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Replace SDL-devel BuildRequires with pkgconfig(sdl): allow to use
  sdl12_compat as an alternative.
* Mon Jun  7 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static)
- Upgrade old rpm constructs (rediffs libdv-fix-no-add-needed.patch
  as p1)
* Mon Feb  3 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Cleanup spec file, remove obsolete conditionals.
- Build playdv as a separate package, removes X11, SDL1 and gtk2
  build dependencies from the library.
* Fri Mar  6 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- User url for source
* Tue Jan 27 2015 crrodriguez@opensuse.org
- libdv-endian.patch : Fix endiannnes tests to rely on the
  compiler instead on the precence of C library definitions
  This is more important for dv_types.h public header because
  BYTE_ORDER is only defined when USE_MISC is.
- libdv-visibility.patch: Export only the public API (dv.h)
  private symbols are now hidden so the unprefixed ones
  do not name-clash with other components of the system.
* Mon Apr 22 2013 dimstar@opensuse.org
- Add libXv-devel BuildRequires: this used to be pulled in by SDL,
  but those dependencies were cleaned up.
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Sat Sep  3 2011 crrodriguez@opensuse.org
- Fix build with no-add-needed
* Fri Jul  8 2011 idonmez@novell.com
- Apply libdv-v4l-2.6.38.patch on openSUSE >= 12.1 to enable v4l
* Fri Jun  4 2010 cristian.rodriguez@opensuse.org
- make it work with selinux enforcing "execmod" (patch by PaxTeam)
* Sat Jan  2 2010 vuntz@opensuse.org
- Add trivial libdv-gtk2.patch to use GTK+ 2 instead of GTK+ 1. The
  patch comes from Debian.
- Change gtk1-compat-devel BuildRequires to gtk2-devel.
- Remove AutoReqProv: it's default now.
- Use makeinstall macro.
- Use includedir instead of /usr/include.
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Jan 13 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Aug  6 2007 olh@suse.de
- update to version 1.0.0
  split libdv4 package which contains only libraries
  remove unused update-desktop-files
  build parallel
* Wed Sep 20 2006 anosek@suse.cz
- fixed compiler warnings [#136823] (warnings.patch)
* Tue Mar 21 2006 bk@suse.de
- Fix playdv abort with Bus Error on empty file (#157631)
* Thu Mar  9 2006 bk@suse.de
- Fix reorder_block() on non-x86 (Brent Casavant, SGI) (#155889),
  restores the older, known good non-x86 loop (no change on x86*)
* Mon Feb 13 2006 bk@suse.de
- make use of MMX and x86 optimsations on x86_64, fixes playback
  of video, 90%% of video frames are dropped without them (~3fps)
- fix memory leak in DV encoder and fix segfault in dvplay
- omit massive printout of warnings which cause interrupted play
- do not require execution stack in assember functions
* Sun Jan 29 2006 aj@suse.de
- Fix BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 26 2005 rguenther@suse.de
- put some meaningful constraints on the asms in mmx.h to
  allow compiling with gcc 4.1 on i386.
* Fri Oct 21 2005 kraxel@suse.de
- splitted away -devel package.
* Mon Sep 26 2005 sbrabec@suse.cz
- Force gtk2 using gtk1-compat-devel.
* Mon Jan 24 2005 kraxel@suse.de
- update to version 0.104
* Fri Aug 20 2004 kraxel@suse.de
- update to version 0.103
* Tue Apr 20 2004 sf@suse.de
- update to version 0.102
* Wed Feb 11 2004 kraxel@suse.de
- update to version 0.101.
- file list updates.
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Mon May 26 2003 kraxel@suse.de
- added dvconnect to the file list.
* Thu May 22 2003 coolo@suse.de
- use BuildRoot (dvconnect removed to build on beta)
* Tue Jan 14 2003 kraxel@suse.de
- updated to version 0.99
* Thu Aug  1 2002 uli@suse.de
- update -> 0.98
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Wed May 15 2002 ro@suse.de
- fix location for pkgconfig file in filelist
* Mon Apr 22 2002 uli@suse.de
- update -> 0.9.5 (bugfixes, enhancements, overhaul of encoder api
  options relating to YUV mismatches, fixes annoying mmx init bug)
* Tue Apr  9 2002 uli@suse.de
- replaced cpuid mmx detection method with parsing of /proc/cpuinfo
  (should be segfault-proof...)
- enabled SDL support
* Tue Apr  2 2002 ray@suse.de
- force MMX-support on ix86 platform
* Tue Jan 22 2002 uli@suse.de
- initial package
